NumberToWordsLetterCase enum

An enumeration representing the supported letter cases for number-to-words conversion.

This enum defines the letter cases for which the NumberToWordsNepali class can convert numbers to their word representations.

Inheritance
Available extensions

Values

upperCase → const NumberToWordsLetterCase

Represents the UPPERCASE letter case.

lowerCase → const NumberToWordsLetterCase

Represents the lowercase letter case.

titleCase → const NumberToWordsLetterCase

Represents the Title Case where the first letter of each word is capitalized.

sentenceCase → const NumberToWordsLetterCase

Represents the Sentence case where the first letter of the first word is capitalized, and the rest of the sentence is in lowercase.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<NumberToWordsLetterCase>
A constant List of the values in this enum, in order of their declaration.