NumberToWordsNepali class

A class to convert numbers to their Nepali word representations.

Constructors

NumberToWordsNepali({NumberToWordsLanguage language = NumberToWordsLanguage.nepali, NumberToWordsLetterCase letterCase = NumberToWordsLetterCase.lowerCase, bool isMonetary = false, String? primaryUnit, String? secondaryUnit, String? separator})
Creates an instance of the NumberToWordsNepali class.

Properties

hashCode int
The hash code for this object.
no setterinherited
isMonetary bool
Specifies whether the conversion should include monetary units (rupees and paisa).
final
language NumberToWordsLanguage
Specifies the language for number to words conversion.
final
letterCase NumberToWordsLetterCase
Specifies the letter case for the converted words.
final
primaryUnit String?
Specifies the primary unit for monetary conversion.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
secondaryUnit String?
Specifies the secondary unit for monetary conversion.
final
separator String?
Specifies the separator to join integer and fractional parts.
final

Methods

convertNumberToWordsNepali(Object number) String
Converts a number to its Nepali word representation.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited